Skip to contents

make_filematrix_row_provider() creates a minimal block-access adapter for filematrix objects. The provider is intended for block-wise sequential access by streaming PCA/PLS backends. It avoids bigmemory mmap write semantics and is not intended to be faster than bigmemory for small random-access matrices.

Usage

is_filematrix_object(x)

make_filematrix_row_provider(X, chunk_size = 1024L)

Arguments

x, X

Object to test or wrap.

chunk_size

Suggested row chunk size for downstream consumers.

Value

is_filematrix_object() returns a logical scalar. The provider is a list with nrow(), ncol(), get_rows(), get_cols(), get_block(), and storage_type = "filematrix".