.finalize_pls_fit: Finalize pls objects
Description
Finalize pls objects
Usage
.finalize_pls_fit(fit, algorithm)
Value
The fit object with normalized naming and class attributes.
Arguments
- fit
Fitted object
- algorithm
Name of the algorithm used to fit the object